package net.sf.resultsetmapper.dbutils;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.List;

import net.sf.resultsetmapper.ReflectionResultSetMapper;
import net.sf.resultsetmapper.ResultSetMapper;

import org.apache.commons.dbutils.BeanProcessor;

/**
 * This Mapper provides <code>BeanProcessor</code> support for use with Apache
 * DBUtils.
 * 
 * @author Warren Mayocchi
 */
public class MappingBeanProcessor<T> extends BeanProcessor {
  
  private ReflectionResultSetMapper<T> resultSetMapper;

  /**
   * Construct a bean processor.
   * 
   * @param targetClass
   */
  public MappingBeanProcessor(Class targetClass) {
    super();
    this.resultSetMapper = new ReflectionResultSetMapper<T>(targetClass);
  }
  
  /**
   * Construct a bean processor.
   * @param targetClasses
   */
  public MappingBeanProcessor(List<Class> targetClasses) {
    super();
    this.resultSetMapper = new ReflectionResultSetMapper<T>(targetClasses);
  }

  /**
   * Override the normal behaviour of the BeanProcessor to use the
   * ReflectionResultSetMapper.
   */
  @Override
  public List toBeanList(ResultSet rs, Class type) throws SQLException {
    return this.resultSetMapper.mapTable(rs);
  }
  
  /**
   * Override the normal behaviour of the BeanProcessor to use the 
   * ReflectionResultSetMapper.
   */
  @Override
  public Object toBean(ResultSet rs, Class type) throws SQLException {
    return this.resultSetMapper.mapRow(rs);    
  }

  /**
   * Obtain the result set mapper, probably so that you can configure it.
   * @return the resultSetMapper
   */
  public ReflectionResultSetMapper<T> getReflectionResultSetMapper() {
    return resultSetMapper;
  }
}