package net.sf.resultsetmapper.spring;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import net.sf.resultsetmapper.ReflectionResultSetMapper;

import org.springframework.jdbc.core.RowCallbackHandler;

/**
 * This implements the Spring RowCallbackHandler interface.
 * 
 * @author Warren Mayocchi
 */
public class CallbackResultSetMapper<T> extends ReflectionResultSetMapper<T> implements
    RowCallbackHandler {

  /**
   * List of created objects.
   */
  private List<T> objects = new ArrayList<T>();

  /**
   * Construct a mapper to create objects of the given target class.
   * @param targetClass Target class.
   */
  public CallbackResultSetMapper(Class targetClass) {
    super(targetClass);
  }
  
  /**
   * Construct a mapper to create objects of the given target classes.
   * @param targetClasses Target classes.
   */
  public CallbackResultSetMapper(List<Class> targetClasses) {
    super(targetClasses);
  }  
  
  /**
   * Implement the <code>RowCallbackHandler</code> interface.
   */
  public void processRow(ResultSet resultSet) throws SQLException {
    objects.add(this.mapRow(resultSet));
  }

  /**
   * Return the objects that have been created.
   * 
   * @return List of the resulting objects.
   */
  public List<T> getObjects() {
    return objects;
  }
}